@@ -1,7 +1,10 @@
 import click
 from bp import parse_jplace, insert_fully_resolved
-from bp.GPL import insert_multifurcating
 
+try:
+    from bp.GPL import insert_multifurcating
+except:
+    insert_multifurcating = None
 
 @click.group()
 def cli():
@@ -20,6 +23,8 @@ def placement(placements, output, method):
     if method == 'fully-resolved':
         f = insert_fully_resolved
     elif method == 'multifurcating':
+        if insert_multifurcating is None:
+            raise ValueError("Please install with 'pip install iow-gpl'")
         f = insert_multifurcating
     else:
         raise ValueError("Unknown method: %s" % method)
